@@ -1,14 +1,14 @@
 import os
 import os.path
-import yaml
 from ..const import CONTEXT_FILE_NAME
+from ..config import Config
 
 
 def new_context(
+    config: Config,
     name: str,
     image: str,
     base: str,
-    cluster_name: str = None,
 ):
     path = os.getcwd()
 
@@ -19,7 +19,7 @@ def new_context(
         os.mkdir(path)
         print('Created context folder', path)
 
-    context = {}
+    context = Config(path=name, config=config)
 
     # image name
     if image is not None:
@@ -31,23 +31,10 @@ def new_context(
         print('Base image:', base)
         context['base'] = base
 
-    # override default cluster
-    if cluster_name is not None:
-        context['cluster'] = cluster_name
-
     context_file = os.path.join(path, CONTEXT_FILE_NAME)
     if os.path.isfile(context_file):
         print('Error: Context file', context_file, 'already exists')
         return
 
-    with open(context_file, 'w') as cf:
-        yaml.dump(
-            {
-                'version': 1,
-                'cowait': context,
-            },
-            stream=cf,
-            sort_keys=False,
-        )
-
+    context.write(context_file)
     print('Created new context definition', context_file)
