@@ -1,10 +1,9 @@
-import asyncio
 import traceback
 from cowait.engine import ClusterProvider
 from cowait.tasks import Task, TaskDefinition, TaskError
-from cowait.types import typed_arguments, typed_return, get_return_type, get_parameter_defaults
+from cowait.types import typed_arguments, typed_return, get_parameter_defaults
+from cowait.storage import StorageBackends
 from .worker_node import WorkerNode
-from .service import FlowLogger, NopLogger
 from .loader import load_task_class
 
 
@@ -14,18 +13,10 @@ async def execute(cluster: ClusterProvider, taskdef: TaskDefinition) -> None:
     """
 
     # create network node
-    node = WorkerNode(taskdef.id)
+    node = WorkerNode(taskdef.id, taskdef.upstream)
 
-    if taskdef.upstream:
-        if taskdef.upstream == 'disabled':
-            node.parent = NopLogger(taskdef.id)
-        else:
-            # start upstream client
-            await node.connect(taskdef.upstream)
-    else:
-        # if we dont have anywhere to forward events, log them to stdout.
-        # logs will be picked up from the top level task by docker/kubernetes.
-        node.parent = FlowLogger(taskdef.id)
+    # start upstream client
+    await node.connect()
 
     try:
         # init should always be the first command sent
@@ -33,6 +24,7 @@ async def execute(cluster: ClusterProvider, taskdef: TaskDefinition) -> None:
 
         # run task within a log capture context
         with node.capture_logs():
+
             # instantiate
             TaskClass = load_task_class(taskdef.name)
             task = TaskClass(
@@ -41,15 +33,29 @@ async def execute(cluster: ClusterProvider, taskdef: TaskDefinition) -> None:
                 node=node,
             )
 
+            # initialize storage
+            setattr(task, 'storage', StorageBackends(taskdef.storage))
+
+            # monitor system resources
+            node.monitor_system(interval=2)
+
             # initialize task
             task.init()
 
             # start http server
-            node.io.create_task(node.http.serve())
+            # this must happen after task.init() so that tasks have a chance
+            # to register extra http routes.
+            node.serve()
+
+            # unpack wrapped function if defined.
+            # allows typechecking of functional tasks
+            taskfunc = task.run
+            if hasattr(TaskClass, '__wraps__'):
+                taskfunc = TaskClass.__wraps__
 
             # prepare arguments
             inputs = {
-                **get_parameter_defaults(task.run),
+                **get_parameter_defaults(taskfunc),
                 **taskdef.inputs,
             }
 
@@ -61,7 +67,7 @@ async def execute(cluster: ClusterProvider, taskdef: TaskDefinition) -> None:
                     'did you forget to return the inputs?')
 
             # typecheck arguments
-            inputs = typed_arguments(task.run, inputs)
+            inputs = typed_arguments(taskfunc, inputs)
 
             # set state to running
             await node.parent.send_run()
@@ -76,8 +82,7 @@ async def execute(cluster: ClusterProvider, taskdef: TaskDefinition) -> None:
             await handle_orphans(task)
 
             # prepare & typecheck result
-            result = typed_return(task.run, result)
-            result_type = get_return_type(task.run)
+            result, result_type = typed_return(taskfunc, result)
 
             # submit result
             await node.parent.send_done(result, result_type.describe())
@@ -100,18 +105,18 @@ async def execute(cluster: ClusterProvider, taskdef: TaskDefinition) -> None:
     finally:
         await node.close()
 
-        # ensure event loop has a chance to run
-        await asyncio.sleep(0.5)
+        # clear active task
+        Task.set_current(None)
 
 
-async def handle_orphans(task: Task, mode: str = 'kill') -> None:
+async def handle_orphans(task: Task, mode: str = 'stop') -> None:
     orphans = filter(lambda child: not child.done, task.subtasks.values())
     for orphan in orphans:
         if mode == 'wait':
             print('~~ waiting for orphaned task', orphan.id)
             await orphan
-        elif mode == 'kill':
-            print('~~ killing orphaned task', orphan.id)
-            orphan.destroy()
+        elif mode == 'stop':
+            print('~~ stopping orphaned task', orphan.id)
+            await orphan.stop()
         else:
             raise RuntimeError(f'Unknown orphan mode {mode}')
